@@ -64,9 +64,9 @@
 bool
 Bhv_PenaltyKick::isKickTaker( rcsc::PlayerAgent * agent )
 {
-    const rcsc::PenaltyKickState * state = agent->world().getPenaltyKickState();
+    const rcsc::PenaltyKickState * state = agent->world().penaltyKickState();
     int taker_unum
-        = 11 - ( ( state->getOurTakerCounter() - 1 ) % 11 );
+        = 11 - ( ( state->ourTakerCounter() - 1 ) % 11 );
     return taker_unum == agent->world().self().unum();
 }
 
@@ -77,10 +77,10 @@ Bhv_PenaltyKick::isKickTaker( rcsc::PlayerAgent * agent )
 bool
 Bhv_PenaltyKick::execute( rcsc::PlayerAgent * agent )
 {
-    const rcsc::PenaltyKickState * state = agent->world().getPenaltyKickState();
-    switch ( agent->world().getGameMode().type() ) {
+    const rcsc::PenaltyKickState * state = agent->world().penaltyKickState();
+    switch ( agent->world().gameMode().type() ) {
     case rcsc::GameMode::PenaltySetup_:
-        if ( state->getCurrentTakerSide() == agent->world().getOurSide() )
+        if ( state->currentTakerSide() == agent->world().ourSide() )
         {
             if ( isKickTaker( agent ) )
             {
@@ -97,7 +97,7 @@ Bhv_PenaltyKick::execute( rcsc::PlayerAgent * agent )
         }
         break;
     case rcsc::GameMode::PenaltyReady_:
-        if ( state->getCurrentTakerSide() == agent->world().getOurSide() )
+        if ( state->currentTakerSide() == agent->world().ourSide() )
         {
             if ( isKickTaker( agent ) )
             {
@@ -114,7 +114,7 @@ Bhv_PenaltyKick::execute( rcsc::PlayerAgent * agent )
         }
         break;
     case rcsc::GameMode::PenaltyTaken_:
-        if ( state->getCurrentTakerSide() == agent->world().getOurSide() )
+        if ( state->currentTakerSide() == agent->world().ourSide() )
         {
             if ( isKickTaker( agent ) )
             {
@@ -132,7 +132,7 @@ Bhv_PenaltyKick::execute( rcsc::PlayerAgent * agent )
         break;
     case rcsc::GameMode::PenaltyScore_:
     case rcsc::GameMode::PenaltyMiss_:
-        if ( agent->world().getGameMode().side() != agent->world().getOurSide()
+        if ( agent->world().gameMode().side() != agent->world().ourSide()
              && agent->world().self().goalie() )
         {
             return doGoalieSetup( agent );
@@ -199,8 +199,8 @@ Bhv_PenaltyKick::doKickerWait( rcsc::PlayerAgent * agent )
 bool
 Bhv_PenaltyKick::doKickerSetup( rcsc::PlayerAgent * agent )
 {
-    const rcsc::PenaltyKickState * state = agent->world().getPenaltyKickState();
-    const double onfield_flag = ( state->getOnfieldSide() == agent->world().getOurSide()
+    const rcsc::PenaltyKickState * state = agent->world().penaltyKickState();
+    const double onfield_flag = ( state->onfieldSide() == agent->world().ourSide()
                                   ? -1.0
                                   : 1.0 );
     const rcsc::Vector2D goal_c( rcsc::ServerParam::i().pitchHalfLength() * onfield_flag,
@@ -240,10 +240,10 @@ Bhv_PenaltyKick::doKickerSetup( rcsc::PlayerAgent * agent )
 bool
 Bhv_PenaltyKick::doKickerReady( rcsc::PlayerAgent * agent )
 {
-    const rcsc::PenaltyKickState * state = agent->world().getPenaltyKickState();
+    const rcsc::PenaltyKickState * state = agent->world().penaltyKickState();
     // stamina recovering...
     if ( agent->world().self().stamina() < rcsc::ServerParam::i().staminaMax() - 10.0
-         && ( agent->world().getTime().cycle()
+         && ( agent->world().time().cycle()
               - state->time().cycle()
               > rcsc::ServerParam::i().penReadyWait() - 3 )
          )
@@ -323,7 +323,7 @@ Bhv_PenaltyKick::doKicker( rcsc::PlayerAgent * agent )
 bool
 Bhv_PenaltyKick::doOneKickShoot( rcsc::PlayerAgent * agent )
 {
-    const rcsc::PenaltyKickState * state = agent->world().getPenaltyKickState();
+    const rcsc::PenaltyKickState * state = agent->world().penaltyKickState();
     const double ball_speed = agent->world().ball().vel().r();
     // ball is moveng --> kick has taken.
     if ( ! rcsc::ServerParam::i().penAllowMultKicks()
@@ -356,8 +356,8 @@ Bhv_PenaltyKick::doOneKickShoot( rcsc::PlayerAgent * agent )
         else
         {
             rcsc::Vector2D goal_c(rcsc::ServerParam::i().pitchHalfLength(), 0.0);
-            if ( state->getOnfieldSide()
-                 == agent->world().getOurSide() )
+            if ( state->onfieldSide()
+                 == agent->world().ourSide() )
             {
                 goal_c.x *= -1.0;
             }
@@ -368,8 +368,8 @@ Bhv_PenaltyKick::doOneKickShoot( rcsc::PlayerAgent * agent )
 
     // decide shot target point
     rcsc::Vector2D shot_point(rcsc::ServerParam::i().pitchHalfLength(), 0.0);
-    if ( state->getOnfieldSide()
-         == agent->world().getOurSide() )
+    if ( state->onfieldSide()
+         == agent->world().ourSide() )
     {
         shot_point *= -1.0;
     }
@@ -409,9 +409,9 @@ Bhv_PenaltyKick::doOneKickShoot( rcsc::PlayerAgent * agent )
 bool
 Bhv_PenaltyKick::doShoot( rcsc::PlayerAgent * agent )
 {
-    const rcsc::PenaltyKickState * state = agent->world().getPenaltyKickState();
+    const rcsc::PenaltyKickState * state = agent->world().penaltyKickState();
 
-    if ( agent->world().getTime().cycle()
+    if ( agent->world().time().cycle()
          - state->time().cycle()
          > rcsc::ServerParam::i().penTakenWait() - 25 )
     {
@@ -440,7 +440,7 @@ bool
 Bhv_PenaltyKick::getShootTarget( const rcsc::PlayerAgent * agent,
                                  rcsc::Vector2D* point, double* first_speed )
 {
-    const rcsc::PenaltyKickState * state = agent->world().getPenaltyKickState();
+    const rcsc::PenaltyKickState * state = agent->world().penaltyKickState();
 
     // check if I am in shootable area.
     if ( agent->world().self().pos().absX() < rcsc::ServerParam::i().pitchHalfLength() - 20.0
@@ -455,7 +455,7 @@ Bhv_PenaltyKick::getShootTarget( const rcsc::PlayerAgent * agent,
     if ( ! opp_goalie )
     {
         rcsc::Vector2D shot_c(rcsc::ServerParam::i().pitchHalfLength(), 0.0);
-        if ( state->getOnfieldSide() == agent->world().getOurSide() )
+        if ( state->onfieldSide() == agent->world().ourSide() )
         {
             shot_c.x *= -1.0;
         }
@@ -480,7 +480,7 @@ Bhv_PenaltyKick::getShootTarget( const rcsc::PlayerAgent * agent,
                            -rcsc::ServerParam::i().goalHalfWidth() + post_buf );
     rcsc::Vector2D shot_r( rcsc::ServerParam::i().pitchHalfLength(),
                            rcsc::ServerParam::i().goalHalfWidth() - post_buf );
-    if ( state->getOnfieldSide() == agent->world().getOurSide() )
+    if ( state->onfieldSide() == agent->world().ourSide() )
     {
         shot_l *= -1.0;
         shot_r *= -1.0;
@@ -520,7 +520,8 @@ Bhv_PenaltyKick::getShootTarget( const rcsc::PlayerAgent * agent,
             }
 
             rcsc::Vector2D ball_pos = agent->world().ball().pos();
-            rcsc::Vector2D ball_vel( rcsc::Vector2D::POLE, tmp_first_speed, angle );
+            rcsc::Vector2D ball_vel =
+                rcsc::Vector2D::polar2vector( tmp_first_speed, angle );
             ball_pos += ball_vel;
             ball_vel *= rcsc::ServerParam::i().ballDecay();
 
@@ -592,10 +593,10 @@ Bhv_PenaltyKick::doDribble( rcsc::PlayerAgent * agent )
 {
     static bool S_target_reversed = false;
 
-    const rcsc::PenaltyKickState * state = agent->world().getPenaltyKickState();
+    const rcsc::PenaltyKickState * state = agent->world().penaltyKickState();
 
     const double onfield_flag
-        = ( state->getOnfieldSide() == agent->world().getOurSide()
+        = ( state->onfieldSide() == agent->world().ourSide()
             ? -1.0 : 1.0 );
     const rcsc::Vector2D goal_c(rcsc::ServerParam::i().pitchHalfLength() * onfield_flag, 0.0);
 
@@ -796,11 +797,11 @@ Bhv_PenaltyKick::doDribble( rcsc::PlayerAgent * agent )
 bool
 Bhv_PenaltyKick::doGoalieWait( rcsc::PlayerAgent * agent )
 {
-    const rcsc::PenaltyKickState * state = agent->world().getPenaltyKickState();
+    const rcsc::PenaltyKickState * state = agent->world().penaltyKickState();
 
     rcsc::Vector2D wait_pos( - rcsc::ServerParam::i().pitchHalfLength() - 2.0, 25.0 );
 
-    if ( state->getOnfieldSide() != agent->world().getOurSide() )
+    if ( state->onfieldSide() != agent->world().ourSide() )
     {
         wait_pos.x *= -1.0;
     }
@@ -833,10 +834,10 @@ Bhv_PenaltyKick::doGoalieWait( rcsc::PlayerAgent * agent )
 bool
 Bhv_PenaltyKick::doGoalieSetup( rcsc::PlayerAgent * agent )
 {
-    const rcsc::PenaltyKickState * state = agent->world().getPenaltyKickState();
+    const rcsc::PenaltyKickState * state = agent->world().penaltyKickState();
 
     rcsc::Vector2D move_point( -50.0, 0.0 );
-    if ( state->getOnfieldSide() != agent->world().getOurSide() )
+    if ( state->onfieldSide() != agent->world().ourSide() )
     {
         move_point.x *= -1.0;
     }
@@ -873,7 +874,7 @@ Bhv_PenaltyKick::doGoalieSetup( rcsc::PlayerAgent * agent )
 bool
 Bhv_PenaltyKick::doGoalie( rcsc::PlayerAgent * agent )
 {
-    const rcsc::PenaltyKickState * state = agent->world().getPenaltyKickState();
+    const rcsc::PenaltyKickState * state = agent->world().penaltyKickState();
 
     ///////////////////////////////////////////////
     // check if catchabale
@@ -881,7 +882,7 @@ Bhv_PenaltyKick::doGoalie( rcsc::PlayerAgent * agent )
                               -rcsc::ServerParam::i().penaltyAreaHalfWidth() + 1.0,
                               rcsc::ServerParam::i().penaltyAreaLength() - 1.0,
                               rcsc::ServerParam::i().penaltyAreaWidth() - 2.0 );
-    if ( state->getOnfieldSide() != agent->world().getOurSide() )
+    if ( state->onfieldSide() != agent->world().ourSide() )
     {
         our_penalty.assign( rcsc::ServerParam::i().theirPenaltyAreaLine() + 1.0,
                             -rcsc::ServerParam::i().penaltyAreaHalfWidth() + 1.0,
@@ -937,13 +938,13 @@ Bhv_PenaltyKick::doGoalie( rcsc::PlayerAgent * agent )
 bool
 Bhv_PenaltyKick::doGoalieBasicMove( rcsc::PlayerAgent * agent )
 {
-    const rcsc::PenaltyKickState * state = agent->world().getPenaltyKickState();
+    const rcsc::PenaltyKickState * state = agent->world().penaltyKickState();
 
     rcsc::Rect2D our_penalty( -rcsc::ServerParam::i().pitchHalfLength(),
                               -rcsc::ServerParam::i().penaltyAreaHalfWidth() + 1.0,
                               rcsc::ServerParam::i().penaltyAreaLength() - 1.0,
                               rcsc::ServerParam::i().penaltyAreaWidth() - 2.0 );
-    if ( state->getOnfieldSide() != agent->world().getOurSide() )
+    if ( state->onfieldSide() != agent->world().ourSide() )
     {
         our_penalty.assign( rcsc::ServerParam::i().theirPenaltyAreaLine() + 1.0,
                             -rcsc::ServerParam::i().penaltyAreaHalfWidth() + 1.0,
@@ -953,7 +954,7 @@ Bhv_PenaltyKick::doGoalieBasicMove( rcsc::PlayerAgent * agent )
 
     ////////////////////////////////////////////////////////////////////////
     // get active interception catch point
-    rcsc::Vector2D move_pos = agent->world().getInterceptTable()->getSelfInterceptPoint();
+    rcsc::Vector2D move_pos = agent->world().interceptTable()->selfInterceptPoint();
 
     if ( our_penalty.contains( move_pos ) )
     {
@@ -969,7 +970,7 @@ Bhv_PenaltyKick::doGoalieBasicMove( rcsc::PlayerAgent * agent )
     rcsc::Vector2D ball_pos;
     if ( agent->world().existKickableOpponent() )
     {
-        ball_pos = agent->world().getOpponentsFromBall().front()->pos();
+        ball_pos = agent->world().opponentsFromBall().front()->pos();
     }
     else
     {
@@ -979,7 +980,7 @@ Bhv_PenaltyKick::doGoalieBasicMove( rcsc::PlayerAgent * agent )
                                                rcsc::ServerParam::i().ballDecay() );
     }
 
-    if ( state->getOnfieldSide() != agent->world().getOurSide() )
+    if ( state->onfieldSide() != agent->world().ourSide() )
     {
         my_pos *= -1.0;
         ball_pos *= -1.0;
@@ -987,7 +988,7 @@ Bhv_PenaltyKick::doGoalieBasicMove( rcsc::PlayerAgent * agent )
 
     move_pos = getGoalieMovePos(ball_pos, my_pos);
 
-    if ( state->getOnfieldSide() != agent->world().getOurSide() )
+    if ( state->onfieldSide() != agent->world().ourSide() )
     {
         move_pos *= -1.0;
     }
@@ -1061,8 +1062,8 @@ Bhv_PenaltyKick::getGoalieMovePos( const rcsc::Vector2D & ball_pos,
     rcsc::Line2D line_m(ball_pos, line_dir);
     rcsc::Line2D goal_line(goal_l, goal_r);
 
-    rcsc::Vector2D intersection;
-    if ( goal_line.intersection( line_m, &intersection ) )
+    rcsc::Vector2D intersection = goal_line.intersection( line_m );
+    if ( intersection )
     {
         rcsc::Line2D line_l( ball_pos, goal_l );
         rcsc::Line2D line_r( ball_pos, goal_r );
@@ -1132,15 +1133,15 @@ Bhv_PenaltyKick::getGoalieMovePos( const rcsc::Vector2D & ball_pos,
     {
         if ( ball_pos.x > 0.0 )
         {
-            return rcsc::Vector2D(min_x , goal_l.y);
+            return rcsc::Vector2D( min_x , goal_l.y );
         }
         else if ( ball_pos.x < 0.0 )
         {
-            return rcsc::Vector2D(min_x , goal_r.y);
+            return rcsc::Vector2D( min_x , goal_r.y );
         }
         else
         {
-            return rcsc::Vector2D(min_x , 0.0);
+            return rcsc::Vector2D( min_x , 0.0 );
         }
     }
 }
@@ -1183,8 +1184,8 @@ Bhv_PenaltyKick::doGoalieSlideChase( rcsc::PlayerAgent * agent )
     rcsc::Line2D my_line( wm.self().pos(), wm.self().body() );
 
 
-    rcsc::Vector2D intersection;
-    if ( ! my_line.intersection( ball_line, &intersection )
+    rcsc::Vector2D intersection = my_line.intersection( ball_line );
+    if ( ! intersection
          || ! ball_ray.inRightDir( intersection ) )
     {
         rcsc::Body_Intercept( false ).execute( agent ); // goalie mode
