@@ -69,9 +69,9 @@ Bhv_SetPlay::execute( rcsc::PlayerAgent * agent )
         return rcsc::Bhv_ScanField().execute( agent );
     }
 
-    switch ( agent->world().getGameMode().type() ) {
+    switch ( agent->world().gameMode().type() ) {
     case rcsc::GameMode::KickOff_:
-        if ( agent->world().getGameMode().side() == agent->world().getOurSide() )
+        if ( agent->world().gameMode().side() == agent->world().ourSide() )
         {
             return Bhv_SetPlayKickOff( M_home_pos ).execute( agent );
         }
@@ -86,7 +86,7 @@ Bhv_SetPlay::execute( rcsc::PlayerAgent * agent )
         }
         break;
     case rcsc::GameMode::KickIn_:
-        if ( agent->world().getGameMode().side() == agent->world().getOurSide() )
+        if ( agent->world().gameMode().side() == agent->world().ourSide() )
         {
             return Bhv_SetPlayKickIn( M_home_pos ).execute( agent );
         }
@@ -96,7 +96,7 @@ Bhv_SetPlay::execute( rcsc::PlayerAgent * agent )
         }
         break;
     case rcsc::GameMode::GoalKick_:
-        if ( agent->world().getGameMode().side() == agent->world().getOurSide() )
+        if ( agent->world().gameMode().side() == agent->world().ourSide() )
         {
             return Bhv_SetPlayGoalKick( M_home_pos ).execute( agent );
         }
@@ -120,7 +120,7 @@ Bhv_SetPlay::execute( rcsc::PlayerAgent * agent )
     }
 
 
-    if ( agent->world().getGameMode().isOurSetPlay( agent->world().getOurSide() ) )
+    if ( agent->world().gameMode().isOurSetPlay( agent->world().ourSide() ) )
     {
         rcsc::dlog.addText( rcsc::Logger::TEAM,
                             "%s:%d: our set play"
@@ -149,7 +149,7 @@ Bhv_SetPlay::get_set_play_dash_power( const rcsc::PlayerAgent * agent )
 {
     const rcsc::WorldModel & wm = agent->world();
 
-    if ( wm.getGameMode().type() == rcsc::GameMode::PenaltySetup_ )
+    if ( wm.gameMode().type() == rcsc::GameMode::PenaltySetup_ )
     {
         return wm.self().getSafetyDashPower( rcsc::ServerParam::i().maxPower() );
     }
