@@ -63,7 +63,7 @@ RoleGoalie::execute( rcsc::PlayerAgent * agent )
     // play_on play
 
     // catchable
-    if ( agent->world().getTime().cycle() > M_last_goalie_kick_time.cycle() + 5
+    if ( agent->world().time().cycle() > M_last_goalie_kick_time.cycle() + 5
          && agent->world().ball().distFromSelf() < agent->world().self().catchableArea() - 0.05
          && our_penalty.contains( agent->world().ball().pos() ) )
     {
