@@ -44,11 +44,10 @@ protected:
 
     /*!
       You can override this method.
-      But you must call TrainerAgent::doInit() in the top of this.
+      But you must call TrainerAgent::doInit() in this method.
     */
     virtual
-    bool doInit( const int argc,
-                 const char * const * argv );
+    bool doInit( rcsc::CmdLineParser & cmd_parser );
 
     //! main decision
     virtual
