@@ -8,21 +8,21 @@
 /*
  *Copyright:
 
-  Copyright (C) Hidehisa AKIYAMA
+ Copyright (C) Hidehisa AKIYAMA
 
-  This code is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2, or (at your option)
-  any later version.
+ This code is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by
+ the Free Software Foundation; either version 2, or (at your option)
+ any later version.
 
-  This code is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
+ This code is distributed in the hope that it will be useful,
+ but WITHOUT ANY WARRANTY; without even the implied warranty of
+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ GNU General Public License for more details.
 
-  You should have received a copy of the GNU General Public License
-  along with this code; see the file COPYING.  If not, write to
-  the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ You should have received a copy of the GNU General Public License
+ along with this code; see the file COPYING.  If not, write to
+ the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 
  *EndCopyright:
  */
@@ -44,6 +44,9 @@
 #include <rcsc/player/intercept_table.h>
 #include <rcsc/player/world_model.h>
 #include <rcsc/player/logger.h>
+#include <rcsc/formation/formation_bpn.h>
+#include <rcsc/formation/formation_dt.h>
+#include <rcsc/formation/formation_uva.h>
 
 #include "role_sample.h"
 
@@ -56,8 +59,6 @@
 #include "role_center_forward.h"
 
 #include "soccer_role.h"
-#include "formation.h"
-#include "formation_uva.h"
 
 #include "strategy.h"
 
@@ -66,9 +67,11 @@ const std::string Strategy::GOAL_KICK_OPP_CONF = "goal-kick-opp.conf";
 const std::string Strategy::GOAL_KICK_OUR_CONF = "goal-kick-our.conf";
 const std::string Strategy::GOALIE_CATCH_OPP_CONF = "goalie-catch-opp.conf";
 const std::string Strategy::GOALIE_CATCH_OUR_CONF = "goalie-catch-our.conf";
-const std::string Strategy::KICKIN_OUR_FORMATION_CONF = "kickin-our-formation.conf";
+
 const std::string Strategy::DEFENSE_FORMATION_CONF = "defense-formation.conf";
 const std::string Strategy::OFFENSE_FORMATION_CONF = "offense-formation.conf";
+const std::string Strategy::KICKIN_OUR_FORMATION_CONF = "kickin-our-formation.conf";
+const std::string Strategy::SETPLAY_OUR_FORMATION_CONF = "setplay-our-formation.conf";
 
 /*-------------------------------------------------------------------*/
 /*!
@@ -84,12 +87,17 @@ Strategy::Strategy()
     M_role_factory[RoleSample::name()] = &RoleSample::create;
 
     M_role_factory[RoleGoalie::name()] = &RoleGoalie::create;
+    M_role_factory["Sweeper"] = &RoleCenterBack::create;
     M_role_factory[RoleCenterBack::name()] = &RoleCenterBack::create;
     M_role_factory[RoleSideBack::name()] = &RoleSideBack::create;
     M_role_factory[RoleDefensiveHalf::name()] = &RoleDefensiveHalf::create;
     M_role_factory[RoleOffensiveHalf::name()] = &RoleOffensiveHalf::create;
     M_role_factory[RoleSideForward::name()] = &RoleSideForward::create;
     M_role_factory[RoleCenterForward::name()] = &RoleCenterForward::create;
+
+    M_formation_factory[rcsc::FormationBPN::name()] = &rcsc::FormationBPN::create;
+    M_formation_factory[rcsc::FormationDT::name()] = &rcsc::FormationDT::create;
+    M_formation_factory[rcsc::FormationUvA::name()] = &rcsc::FormationUvA::create;
 }
 
 /*-------------------------------------------------------------------*/
@@ -153,6 +161,11 @@ Strategy::read( const std::string & config_dir )
         std::cerr << "Failed to read kickin our formation" << std::endl;
         return false;
     }
+    if ( ! readSetPlayOurFormation( configpath ) )
+    {
+        std::cerr << "Failed to read setplay our formation" << std::endl;
+        return false;
+    }
 
     return true;
 }
@@ -161,7 +174,7 @@ Strategy::read( const std::string & config_dir )
 /*!
 
 */
-boost::shared_ptr< Formation >
+boost::shared_ptr< rcsc::Formation >
 Strategy::readFormation( const std::string & filepath )
 {
     std::ifstream fin( filepath.c_str() );
@@ -170,36 +183,44 @@ Strategy::readFormation( const std::string & filepath )
         std::cerr << __FILE__ << ": " << __LINE__
                   << " ***ERROR*** failed to open file [" << filepath << "]"
                   << std::endl;
-        return boost::shared_ptr< Formation >( static_cast< Formation * >( 0 ) );
+        return boost::shared_ptr< rcsc::Formation >
+            ( static_cast< rcsc::Formation * >( 0 ) );
+    }
+
+    std::string temp, type;
+    fin >> temp >> type; // read training method type name
+    fin.seekg( 0 );
+
+    boost::shared_ptr< rcsc::Formation > ptr = createFormation( type );
+
+    if ( ! ptr )
+    {
+        std::cerr << __FILE__ << ": " << __LINE__
+                  << " ***ERROR*** failed to create formation [" << filepath << "]"
+                  << std::endl;
+        return boost::shared_ptr< rcsc::Formation >
+            ( static_cast< rcsc::Formation * >( 0 ) );
     }
 
-    boost::shared_ptr< Formation > ptr( new Formation );
     if ( ! ptr->read( fin ) )
     {
         std::cerr << __FILE__ << ": " << __LINE__
                   << " ***ERROR*** failed to read formation [" << filepath << "]"
                   << std::endl;
-        return boost::shared_ptr< Formation >( static_cast< Formation * >( 0 ) );
+        return boost::shared_ptr< rcsc::Formation >
+            ( static_cast< rcsc::Formation * >( 0 ) );
     }
 
     for ( int unum = 1; unum <= 11; ++unum )
     {
-        boost::shared_ptr< const FormationParam > fparam = ptr->param( unum );
-        if ( ! fparam )
-        {
-            std::cerr << __FILE__ << ": " << __LINE__
-                      << " ***ERROR*** detected Null formation param in ["
-                      << filepath << "]"
-                      << std::endl;
-            return boost::shared_ptr< Formation >( static_cast< Formation * >( 0 ) );
-        }
-        if ( M_role_factory.find( fparam->getRoleName() ) == M_role_factory.end() )
+        if ( M_role_factory.find( ptr->getRoleName( unum ) ) == M_role_factory.end() )
         {
             std::cerr << __FILE__ << ": " << __LINE__
                       << " ***ERROR*** Unsupported role name ["
-                      << fparam->getRoleName() << "] is included in in ["
+                      << ptr->getRoleName( unum ) << "] is appered in ["
                       << filepath << "]" << std::endl;
-            return boost::shared_ptr< Formation >( static_cast< Formation * >( 0 ) );
+            return boost::shared_ptr< rcsc::Formation >
+                ( static_cast< rcsc::Formation * >( 0 ) );
         }
     }
 
@@ -394,6 +415,30 @@ Strategy::readGoalieCatchOppPos( const std::string & configpath )
     return true;
 }
 
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+boost::shared_ptr< rcsc::Formation >
+Strategy::createFormation( const std::string & type_name ) const
+{
+    // get role factory of this role name
+    std::map< std::string, FormationCreator >::const_iterator factory
+        = M_formation_factory.find( type_name );
+    if ( factory == M_formation_factory.end() )
+    {
+        std::cerr << __FILE__ << ": " << __LINE__
+                  << " ***ERROR*** formation type ["
+                  << type_name << "] is not supported"
+                  << std::endl;
+        return boost::shared_ptr< rcsc::Formation >
+            ( static_cast< rcsc::Formation * >( 0 ) );
+    }
+
+    boost::shared_ptr< rcsc::Formation > f( factory->second() );
+    return f;
+}
+
 /*-------------------------------------------------------------------*/
 /*!
   create role instance
@@ -410,7 +455,7 @@ Strategy::createRole( const int number,
         return boost::shared_ptr< SoccerRole >( static_cast< SoccerRole * >( 0 ) );
     }
 
-    boost:: shared_ptr< const Formation > formation = getFormation( world );
+    boost:: shared_ptr< const rcsc::Formation > formation = getFormation( world );
     if ( ! formation )
     {
         std::cerr << __FILE__ << ": " << __LINE__
@@ -418,85 +463,11 @@ Strategy::createRole( const int number,
         return boost::shared_ptr< SoccerRole >( static_cast< SoccerRole * >( 0 ) );
     }
 
-    const boost::shared_ptr< const FormationParam > fparam
-        = formation->param( number );
-    if ( ! fparam )
-    {
-        std::cerr << __FILE__ << ": " << __LINE__
-                  << " ***ERROR*** faled to create role. Null formation param"
-                  << std::endl;
-        return boost::shared_ptr< SoccerRole >( static_cast< SoccerRole * >( 0 ) );
-    }
-
-
-    ///// delete here, if you do not use SBSP formation ////////
-    if ( uva::Formations::instance().valid() )
-    {
-        uva::PlayerT type = uva::Formations::instance()
-            .getPlayerType( number - 1, uva::FT_433_OFFENSIVE );
-        switch ( type ) {
-        case uva::PT_GOALKEEPER:
-            {
-                boost::shared_ptr< SoccerRole > role_ptr( RoleGoalie::create( formation ) );
-                return role_ptr;
-            }
-            break;
-        case uva::PT_DEFENDER_CENTRAL:
-            {
-                boost::shared_ptr< SoccerRole > role_ptr( RoleCenterBack::create( formation ) );
-                return role_ptr;
-            }
-            break;
-        case uva::PT_DEFENDER_SWEEPER:
-            {
-                boost::shared_ptr< SoccerRole > role_ptr( RoleCenterBack::create( formation ) );
-                return role_ptr;
-            }
-            break;
-        case uva::PT_DEFENDER_WING:
-            {
-                boost::shared_ptr< SoccerRole > role_ptr( RoleSideBack::create( formation ) );
-                return role_ptr;
-            }
-            break;
-        case uva::PT_MIDFIELDER_CENTER:
-            {
-                boost::shared_ptr< SoccerRole > role_ptr( RoleDefensiveHalf::create( formation ) );
-                return role_ptr;
-            }
-            break;
-        case uva::PT_MIDFIELDER_WING:
-            {
-                boost::shared_ptr< SoccerRole > role_ptr( RoleOffensiveHalf::create( formation ) );
-                return role_ptr;
-            }
-            break;
-        case uva::PT_ATTACKER_WING:
-            {
-                boost::shared_ptr< SoccerRole > role_ptr( RoleSideForward::create( formation ) );
-                return role_ptr;
-            }
-            break;
-        case uva::PT_ATTACKER:
-            {
-                boost::shared_ptr< SoccerRole > role_ptr( RoleCenterForward::create( formation ) );
-                return role_ptr;
-            }
-            break;
-        default:
-            return boost::shared_ptr< SoccerRole >( static_cast< SoccerRole * >( 0 ) );
-            break;
-        }
-
-    }
-    /////////////////////////////////////////////////////////
-
-
-    const std::string & rolename = fparam->getRoleName();
+    const std::string rolename = formation->getRoleName( number );
 
     // get role factory of this role name
-    std::map< std::string, RoleCreator >::const_iterator
-        factory = M_role_factory.find( rolename );
+    std::map< std::string, RoleCreator >::const_iterator factory
+        = M_role_factory.find( rolename );
     if ( factory == M_role_factory.end() )
     {
         std::cerr << __FILE__ << ": " << __LINE__
@@ -538,7 +509,6 @@ Strategy::getPosWhenGoalKickOpp( const int number ) const
 {
     if ( number < 1 || 11 < number )
     {
-
         std::cerr << __FILE__ << ": " << __LINE__
                   << " ***ERROR*** Invalid player number " << number
                   << std::endl;
@@ -557,12 +527,12 @@ Strategy::getPosWhenGoalKickOur( const int number ) const
 {
     if ( number < 1 || 11 < number )
     {
-
         std::cerr << __FILE__ << ": " << __LINE__
                   << " ***ERROR*** Invalid player number " << number
                   << std::endl;
         return rcsc::Vector2D( -50.0, -30.0 );
     }
+
     return M_goal_kick_our_pos[number - 1];
 }
 
@@ -575,12 +545,12 @@ Strategy::getPosWhenGoalieCatchOpp( const int number ) const
 {
     if ( number < 1 || 11 < number )
     {
-
         std::cerr << __FILE__ << ": " << __LINE__
                   << " ***ERROR*** Invalid player number " << number
                   << std::endl;
         return rcsc::Vector2D( -50.0, -30.0 );
     }
+
     return M_goalie_catch_opp_pos[number - 1];
 }
 
@@ -598,6 +568,7 @@ Strategy::getPosWhenGoalieCatchOur( const int number ) const
                   << std::endl;
         return rcsc::Vector2D( -50.0, -30.0 );
     }
+
     return M_goalie_catch_our_pos[number - 1];
 }
 
@@ -607,30 +578,33 @@ Strategy::getPosWhenGoalieCatchOur( const int number ) const
 */
 rcsc::Vector2D
 Strategy::getSetPlayPosition( const int number,
-                              const Formation & formation,
+                              const rcsc::Formation & formation,
                               const rcsc::WorldModel & world ) const
 {
-    if ( world.getGameMode().type() == rcsc::GameMode::GoalKick_ )
+    if ( world.gameMode().type() == rcsc::GameMode::GoalKick_ )
     {
-        if ( world.getGameMode().side() == world.getOurSide() )
+        if ( world.gameMode().side() == world.ourSide() )
         {
             return getPosWhenGoalKickOur( number );
         }
-        if ( world.getGameMode().side() != world.getOurSide() )
+
+        if ( world.gameMode().side() != world.ourSide() )
         {
             return getPosWhenGoalKickOpp( number );
         }
     }
-    if ( world.getGameMode().type() == rcsc::GameMode::GoalieCatch_ )
+
+    if ( world.gameMode().type() == rcsc::GameMode::GoalieCatch_ )
     {
-        if ( world.getGameMode().side() == world.getOurSide() )
+        if ( world.gameMode().side() == world.ourSide() )
         {
             rcsc::dlog.addText( rcsc::Logger::TEAM,
                                 "%s: Strategy. get our galie catch mode position"
                                 ,__FILE__ );
             return getPosWhenGoalieCatchOur( number );
         }
-        if ( world.getGameMode().side() != world.getOurSide() )
+
+        if ( world.gameMode().side() != world.ourSide() )
         {
             return getPosWhenGoalieCatchOpp( number );
         }
@@ -647,7 +621,7 @@ Strategy::getSetPlayPosition( const int number,
 
 
     bool our_setplay = false;
-    switch ( world.getGameMode().type() ) {
+    switch ( world.gameMode().type() ) {
     case rcsc::GameMode::KickOff_:
     case rcsc::GameMode::KickIn_:
     case rcsc::GameMode::CornerKick_:
@@ -655,7 +629,7 @@ Strategy::getSetPlayPosition( const int number,
     case rcsc::GameMode::FreeKick_:
     case rcsc::GameMode::GoalieCatch_:
     case rcsc::GameMode::IndFreeKick_:
-        if ( world.getGameMode().side() == world.getOurSide() )
+        if ( world.gameMode().side() == world.ourSide() )
         {
             our_setplay = true;
         }
@@ -664,7 +638,7 @@ Strategy::getSetPlayPosition( const int number,
     case rcsc::GameMode::FreeKickFault_:
     case rcsc::GameMode::BackPass_:
     case rcsc::GameMode::CatchFault_:
-        if ( world.getGameMode().side() != world.getOurSide() )
+        if ( world.gameMode().side() != world.ourSide() )
         {
             our_setplay = true;
         }
@@ -673,24 +647,10 @@ Strategy::getSetPlayPosition( const int number,
         break;
     }
 
-    if ( world.getGameMode().type() == rcsc::GameMode::GoalieCatch_
-         && world.getGameMode().side() == world.getOurSide() )
+    if ( ! our_setplay )
     {
-        base_pos.x = -40.0;
-        base_pos.y = 0.0;
-    }
-    else if ( world.getGameMode().type() == rcsc::GameMode::GoalKick_
-              && world.getGameMode().side() == world.getOurSide() )
-    {
-        base_pos.x = -40.0;
-        base_pos.y = 0.0;
-    }
-    else if ( ! our_setplay )
-    {
-        base_pos.x = std::max( -41.0, base_pos.x - 15.0 );
-        base_pos.y = std::min( rcsc::ServerParam::i().pitchHalfLength(),
-                               base_pos.y * 1.1 );
-
+        base_pos.x = std::max( -50.0,
+                               base_pos.x - 10.0 );
     }
 
     rcsc::Vector2D home_pos = formation.getPosition( number, base_pos );
@@ -698,10 +658,10 @@ Strategy::getSetPlayPosition( const int number,
     // to onside
     if ( rcsc::ServerParam::i().useOffside() )
     {
-        if ( world.getGameMode().type() != rcsc::GameMode::KickIn_
-             || world.getGameMode().side() != world.getOurSide() )
+        if ( world.gameMode().type() != rcsc::GameMode::KickIn_
+             || world.gameMode().side() != world.ourSide() )
         {
-            home_pos.x = std::min( home_pos.x, world.getOffsideLineX() - 0.5 );
+            home_pos.x = std::min( home_pos.x, world.offsideLineX() - 0.5 );
         }
     }
 
@@ -712,16 +672,22 @@ Strategy::getSetPlayPosition( const int number,
 /*!
 
 */
-boost:: shared_ptr< const Formation >
+boost:: shared_ptr< const rcsc::Formation >
 Strategy::getFormation( const rcsc::WorldModel & world ) const
 {
-    if ( world.getGameMode().type() == rcsc::GameMode::KickIn_ )
+    if ( world.gameMode().type() == rcsc::GameMode::KickIn_
+         || world.gameMode().type() == rcsc::GameMode::CornerKick_ )
     {
-        if ( world.getOurSide() == world.getGameMode().side() )
+        if ( world.ourSide() == world.gameMode().side() )
         {
             return M_kickin_our_formation;
         }
     }
+    else if ( world.gameMode().isOurSetPlay( world.ourSide() ) )
+    {
+        // our set-play
+        return M_setplay_our_formation;
+    }
 
     if ( world.ball().pos().x > 0.0 )
     {
@@ -731,79 +697,6 @@ Strategy::getFormation( const rcsc::WorldModel & world ) const
     {
         return M_defense_formation;
     }
-
-#if 0
-    if ( world.getGameMode().type() == GameMode::KickIn_ )
-    {
-        if ( world.getOurSide() == world.getGameMode().side() )
-        {
-            return M_kickin_our;
-        }
-        else
-        {
-            return M_kickin_opponent;
-        }
-    }
-#endif
-
-
-#if 0
-    if ( world.ball().pos().x > 20.0 )
-    {
-        return M_attack_area_offense;
-    }
-    else if ( world.ball().pos().x > -20.0 )
-    {
-        return M_middle_area_offense;
-    }
-    else
-    {
-        return M_block_area_defense;
-    }
-#endif
-#if 0
-    const InterceptTable * table = world.getInterceptTable();
-    //const int self_min = table->getSelfReachCycle();
-    const int mate_min = table->getTeammateReachCycle();
-    const int opp_min = table->getOpponentReachCycle();
-
-    // other playmode including playon
-    if ( world.ball().pos().x > 25.0 )
-    {
-        if ( world.existKickableTeammate()
-             || mate_min < opp_min )
-        {
-            return M_attack_area_offense;
-        }
-
-        return M_attack_area_defense;
-    }
-
-    if ( world.ball().pos().x > -20.0 )
-    {
-        if ( ( world.existKickableTeammate()
-               && ! world.existKickableOpponent() )
-             || mate_min < opp_min - 3 )
-        {
-            return M_middle_area_offense;
-        }
-
-        return M_middle_area_defense;
-    }
-
-    // block area
-
-    {
-        if ( ( world.existKickableTeammate()
-               && ! world.existKickableOpponent() )
-             || mate_min < opp_min - 5 )
-        {
-            return M_block_area_offense;
-        }
-
-    }
-    return M_block_area_defense;
-#endif
 }
 
 /*-------------------------------------------------------------------*/
@@ -851,11 +744,24 @@ Strategy::readKickInOurFormation( const std::string & configpath )
 /*-------------------------------------------------------------------*/
 /*!
 
+*/
+bool
+Strategy::readSetPlayOurFormation( const std::string & configpath )
+{
+    std::string filepath = configpath + SETPLAY_OUR_FORMATION_CONF;
+
+    M_setplay_our_formation = readFormation( filepath );
+
+    return ( M_setplay_our_formation );
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
 */
 Strategy::BallArea
 Strategy::get_ball_area( const rcsc::Vector2D & ball_pos )
 {
-    //if (ball_pos.x > 41.5)
     if ( ball_pos.x > 39.0 )
     {
         if ( ball_pos.absY() > 17.0 )
